#! /bin/sh
$XGETTEXT `find -name '*.cpp'` -o $podir/pimsettingexporter.pot

